Whether an xcms object supports and currently has feature definitions. Plain MsExperiment has no hasFeatures method; only XcmsExperiment / XCMSnExp.
dot-xcms_has_features.RdWhether an xcms object supports and currently has feature definitions. Plain MsExperiment has no hasFeatures method; only XcmsExperiment / XCMSnExp.