Subset an igraph to selected vertices
igraph_filter_vertex.RdKeeps only vertices in v and removes all others.
Arguments
- ig
An
igraphobject.- v
Vertex indices, names, or a logical vector (passed to
igraph::V).
igraph_filter_vertex.RdKeeps only vertices in v and removes all others.
An igraph object.
Vertex indices, names, or a logical vector (passed to igraph::V).