setwdActivedFilePath
setwdActivedFilePath.RdSet Working Directory as currently opened file in RStudio editor,
see rstudioapi::getSourceEditorContext()
setwdActivedFilePath.RdSet Working Directory as currently opened file in RStudio editor,
see rstudioapi::getSourceEditorContext()