Skip to contents

Writes a data frame or other object to an Excel file, creating the directory if it does not exist.

Usage

write.xlsx(data, file.dir)

Arguments

data

Data frame or object to write to Excel.

file.dir

File path for the output Excel file.

Value

Invisible NULL.