Filter Peaks Below Noise Level
Spectra_filter_noise.RdFilters out mass spectral peaks that are below the noise level.
Requires that a noise spectrum variable has been previously calculated
(e.g., using Spectra_get_noise). Peaks with intensity less than or equal
to the noise level are removed.