Estimate Noise Level for Spectra
Spectra_get_noise.RdEstimates the noise level for each spectrum using a density-based method. The noise is estimated as the intensity value at the maximum of the log10-transformed intensity density distribution. Also calculates signal-to-noise ratio (SNR).