Load RData File as Variable
load_as_var.RdLoads an RData file and returns the single variable it contains. The function validates that exactly one variable exists in the file before loading.
load_as_var.RdLoads an RData file and returns the single variable it contains. The function validates that exactly one variable exists in the file before loading.