Matrix Subtraction of Two Vectors
matrixSub.RdExpands two vectors into matrices and computes element-wise subtraction,
creating a full difference matrix where each element (i,j) equals v1[i] - v2[j].
matrixSub.RdExpands two vectors into matrices and computes element-wise subtraction,
creating a full difference matrix where each element (i,j) equals v1[i] - v2[j].