Open Directory in File Explorer
open_dir.RdOpens a directory in the system's file explorer (Windows Explorer on Windows). If a file path is provided, opens the containing directory.
Usage
open_dir(x = getwd())open_dir.RdOpens a directory in the system's file explorer (Windows Explorer on Windows). If a file path is provided, opens the containing directory.
open_dir(x = getwd())