Set RStudio Files Pane Directory
setRStudioDir.RdNavigates the RStudio files pane to the specified directory or the directory of the currently active file.
Usage
setRStudioDir(path = rstudioapi::getSourceEditorContext()$path)setRStudioDir.RdNavigates the RStudio files pane to the specified directory or the directory of the currently active file.
setRStudioDir(path = rstudioapi::getSourceEditorContext()$path)