write.xlsx.Rd
Writes a data frame or other object to an Excel file, creating the directory if it does not exist.
write.xlsx(data, file.dir)
Data frame or object to write to Excel.
File path for the output Excel file.
Invisible NULL.